@@ -22,6 +22,6 @@ SAMPLE_STOCK_CODES = ['000001', '000783', '000778', '603220', '601318', '000338'
 SAMPLE_ETF_CODES = ['510300', '512880', '510500', '510050', '159915', '512660', '512980', '510410']
 
 # 上证指数 上证50 沪深300 中证500 中证1000  科创50
-# 深证成指 国证成长（399370）国证价值（399371）国证基金(399379) 国证ETF(399380)
+# 深证成指(399001) 创业板指(399006) 国证成长（399370）国证价值（399371）国证基金(399379) 国证ETF(399380)
 IMPORTANT_INDEX = ['000001', '000016', '000300', '000905', '000852', '000688',
-                   '399001', '399370', '399371', '399379', '399380']
+                   '399001', '399006', '399370', '399371', '399379', '399380']
