@@ -46,7 +46,7 @@ class StockDetail(StockMetaBase, TradableEntity):
     net_winning_rate = Column(Float)
 
 
-register_schema(providers=['joinquant', 'eastmoney', 'exchange'], db_name='stock_meta',
+register_schema(providers=['exchange', 'joinquant', 'eastmoney', 'em'], db_name='stock_meta',
                 schema_base=StockMetaBase)
 # the __all__ is generated
-__all__ = ['Stock', 'StockDetail']
\ No newline at end of file
+__all__ = ['Stock', 'StockDetail']
