@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 import argparse
-from typing import List, Union, Type, Optional
+from typing import List, Union, Type
 
 import pandas as pd
 
@@ -65,9 +65,6 @@ class MaFactor(TechnicalFactor):
                          computing_window, keep_all_timestamp, fill_method, effective_number, transformer, None,
                          need_persist, only_compute_factor, factor_name, clear_state, only_load_factor, adjust_type)
 
-    def drawer_factor_df_list(self) -> Optional[List[pd.DataFrame]]:
-        return [self.factor_df[self.transformer.indicators]]
-
 
 class CrossMaFactor(MaFactor):
     def compute_result(self):
@@ -80,7 +77,7 @@ class CrossMaFactor(MaFactor):
             current_col = col
 
         print(self.factor_df[s])
-        self.result_df = s.to_frame(name='score')
+        self.result_df = s.to_frame(name='filter_result')
 
 
 class VolumeUpMaFactor(TechnicalFactor):
@@ -140,25 +137,32 @@ class VolumeUpMaFactor(TechnicalFactor):
 
         # 价格刚上均线
         cols = [f'ma{window}' for window in self.windows]
-        filter_se = (self.factor_df['close'] > self.factor_df[cols[0]]) & (
+        filter_up = (self.factor_df['close'] > self.factor_df[cols[0]]) & (
                 self.factor_df['close'] < 1.1 * self.factor_df[cols[0]])
         for col in cols[1:]:
             if self.over_mode == 'and':
-                filter_se = filter_se & (self.factor_df['close'] > self.factor_df[col])
+                filter_up = filter_up & ((self.factor_df['close'] > self.factor_df[col]) & (
+                        self.factor_df['close'] < 1.1 * self.factor_df[col]))
             else:
-                filter_se = filter_se | (self.factor_df['close'] > self.factor_df[col])
+                filter_up = filter_up | ((self.factor_df['close'] > self.factor_df[col]) & (
+                        self.factor_df['close'] < 1.1 * self.factor_df[col]))
         # 放量
         if self.vol_windows:
             vol_cols = [f'vol_ma{window}' for window in self.vol_windows]
-            filter_se = filter_se & (self.factor_df['volume'] > 2 * self.factor_df[vol_cols[0]])
+            filter_vol = (self.factor_df['volume'] > 2 * self.factor_df[vol_cols[0]])
             for col in vol_cols[1:]:
-                filter_se = filter_se & (self.factor_df['volume'] > 2 * self.factor_df[col])
+                filter_vol = filter_vol & (self.factor_df['volume'] > 2 * self.factor_df[col])
 
         # 成交额过滤
-        filter_se = filter_se & (self.factor_df['turnover'] > self.turnover_threshold)
+        s = filter_up & filter_vol & (self.factor_df['turnover'] > self.turnover_threshold)
 
-        print(self.factor_df[filter_se])
-        self.result_df = filter_se.to_frame(name='score')
+        s[s == False] = None
+        s = s.groupby(level=0).fillna(method='ffill', limit=40)
+        s[s.isna()] = False
+
+        filter_result = filter_up & s
+
+        self.result_df = filter_result.to_frame(name='filter_result')
 
 
 class CrossMaVolumeFactor(VolumeUpMaFactor):
@@ -174,7 +178,7 @@ class CrossMaVolumeFactor(VolumeUpMaFactor):
         filter_se = filter_se & (self.factor_df['turnover'] > self.turnover_threshold)
 
         print(self.factor_df[filter_se])
-        self.result_df = filter_se.to_frame(name='score')
+        self.result_df = filter_se.to_frame(name='filter_result')
 
 
 if __name__ == '__main__':
@@ -200,4 +204,4 @@ if __name__ == '__main__':
                               end_timestamp=now_pd_timestamp(), level=level, need_persist=False)
     print(factor.result_df)
 # the __all__ is generated
-__all__ = ['get_ma_factor_schema', 'MaFactor', 'CrossMaFactor', 'VolumeUpMaFactor', 'CrossMaVolumeFactor']
\ No newline at end of file
+__all__ = ['get_ma_factor_schema', 'MaFactor', 'CrossMaFactor', 'VolumeUpMaFactor', 'CrossMaVolumeFactor']
