@@ -44,7 +44,7 @@ class EastmoneyBlockRecorder(Recorder):
             if the_list:
                 df = pd.DataFrame.from_records(the_list)
                 df_to_db(data_schema=self.data_schema, df=df, provider=self.provider,
-                         force_update=True)
+                         force_update=self.force_update)
             self.logger.info(f"finish record sina blocks:{category.value}")
 
 
